#include "obgtkVBox.h"

@implementation Gtk_VBox
- castGtkVBox:(GtkVBox *)castitem
{
  self = [super castGtkBox:GTK_BOX(castitem)];
  return self;
}

- init
{
  return [self initWithBoxInfo:FALSE setSpacing:5];
}

- initWithBoxInfo:(gint) homogeneous
 setSpacing:(gint) spacing
{
  return [self castGtkVBox:GTK_VBOX(gtk_vbox_new(homogeneous, spacing))];
}
@end
